@@ -20,7 +20,6 @@
 """
 """
 
-import fedmsg
 from fedmsg.commands import BaseCommand
 from fedmsg.consumers.gateway import GatewayConsumer
 
@@ -34,13 +33,12 @@ class GatewayCommand(BaseCommand):
     messages from "outside the bus" back in.
 
     The special zmq endpoint is specified by the presence of
-    :term:`fedmsg.consumers.gateway.port` in the config.
+    :ref:`conf-fedmsg.consumers.gateway.port` in the config.
 
     This service is what makes using ":doc:`consuming`" outside the
     VPN/firewalled bus environment possible.
     """
     name = 'fedmsg-gateway'
-    daemonizable = True
     extra_args = []
 
     def run(self):
