@@ -24,16 +24,12 @@ import copy
 import os
 import socket
 
-from time import sleep, time
-from uuid import uuid4
+from time import sleep
 
-from moksha.hub.tests.test_hub import simulate_reactor
-from moksha.hub.hub import MokshaHub
 from moksha.hub import CentralMokshaHub
-from fedmsg.core import FedMsgContext
-
-from nose.tools import eq_, assert_true, assert_false, raises
+from fedmsg.tests.common import requires_network
 
+from .test_hub import simulate_reactor
 import fedmsg.config
 import fedmsg.consumers
 import fedmsg.encoding
@@ -78,13 +74,14 @@ class TestHub(unittest.TestCase):
         self.hub = CentralMokshaHub(config=config)
 
         # fully qualified
-        self.fq_topic = "com.test_prefix.dev.threadtest.foo"
+        self.fq_topic = "org.fedoraproject.dev.threadtest.foo"
         # short version
         self.topic = "foo"
 
     def tearDown(self):
         self.hub.close()
 
+    @requires_network
     def test_multi_threaded(self):
         """ Send messages from 5 concurrent threads. """
         messages_received = []
@@ -116,8 +113,8 @@ class TestHub(unittest.TestCase):
         simulate_reactor(sleep_duration)
         sleep(sleep_duration)
 
-        eq_(len(messages_received), 5)
-        eq_(messages_received[0]['msg'], secret)
+        self.assertEqual(len(messages_received), 5)
+        self.assertEqual(messages_received[0]['msg'], secret)
 
     def test_reinitialize(self):
         """ In a thread, try to destroy and re-init the API. """
@@ -145,5 +142,6 @@ class TestHub(unittest.TestCase):
 
         assert(self.test_reinit_success)
 
+
 if __name__ == '__main__':
     unittest.main()
